@@ -1,21 +1,8 @@
 /*
-*   Copyright (C) 2017 by Marco Martin <mart@kde.org>
-*
-*   This program is free software; you can redistribute it and/or modify
-*   it under the terms of the GNU Library General Public License as
-*   published by the Free Software Foundation; either version 2, or
-*   (at your option) any later version.
-*
-*   This program is distributed in the hope that it will be useful,
-*   but WITHOUT ANY WARRANTY; without even the implied warranty of
-*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-*   GNU Library General Public License for more details
-*
-*   You should have received a copy of the GNU Library General Public
-*   License along with this program; if not, write to the
-*   Free Software Foundation, Inc.,
-*   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-*/
+ *  SPDX-FileCopyrightText: 2017 Marco Martin <mart@kde.org>
+ *
+ *  SPDX-License-Identifier: LGPL-2.0-or-later
+ */
 
 #ifndef FORMLAYOUTATTACHED_H
 #define FORMLAYOUTATTACHED_H
@@ -98,12 +85,12 @@ class FormLayoutAttached : public QObject
      * If true a checkbox is prepended to the FormLayout item.
      */
     Q_PROPERTY(bool checkable READ checkable WRITE setCheckable NOTIFY checkableChanged)
-    
+
     /**
      * This property is true when the checkbox of the FormLayout item is checked, @see checkable.
      */
     Q_PROPERTY(bool checked READ checked WRITE setChecked NOTIFY checkedChanged)
-    
+
     /**
      * This property holds whether the label and the checkbox of the FormLayout item receive mouse and keyboard events.
      */
@@ -115,7 +102,7 @@ class FormLayoutAttached : public QObject
      * A buddy item is useful for instance when the label has a keyboard accelerator,
      * which on triggered will be given active keyboard focus to.
      */
-    Q_PROPERTY(QQuickItem *buddyFor READ buddyFor CONSTANT)
+    Q_PROPERTY(QQuickItem *buddyFor READ buddyFor WRITE setBuddyFor NOTIFY buddyForChanged)
 
 public:
 
@@ -129,17 +116,18 @@ public:
 
     void setIsSection(bool section);
     bool isSection() const;
-    
+
     void setCheckable(bool checkable);
     bool checkable() const;
-    
+
     void setChecked(bool checked);
     bool checked() const;
-    
+
     void setEnabled(bool enabled);
     bool enabled() const;
 
     QQuickItem *buddyFor() const;
+    void setBuddyFor(QQuickItem *buddyfor);
 
     //QML attached property
     static FormLayoutAttached *qmlAttachedProperties(QObject *object);
@@ -150,6 +138,7 @@ Q_SIGNALS:
     void checkableChanged();
     void checkedChanged();
     void enabledChanged();
+    void buddyForChanged();
 
 private:
     QString m_label;
