@@ -1,21 +1,8 @@
 /*
-*   Copyright (C) 2017 by Marco Martin <mart@kde.org>
-*
-*   This program is free software; you can redistribute it and/or modify
-*   it under the terms of the GNU Library General Public License as
-*   published by the Free Software Foundation; either version 2, or
-*   (at your option) any later version.
-*
-*   This program is distributed in the hope that it will be useful,
-*   but WITHOUT ANY WARRANTY; without even the implied warranty of
-*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-*   GNU Library General Public License for more details
-*
-*   You should have received a copy of the GNU Library General Public
-*   License along with this program; if not, write to the
-*   Free Software Foundation, Inc.,
-*   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-*/
+ *  SPDX-FileCopyrightText: 2017 by Marco Martin <mart@kde.org>
+ *
+ *  SPDX-License-Identifier: LGPL-2.0-or-later
+ */
 
 #include "basictheme_p.h"
 #include <QQmlEngine>
@@ -66,7 +53,7 @@ QObject *BasicThemeDeclarative::instance(const BasicTheme *theme)
             import org.kde.kirigami 2.0 as Kirigami\n\
             QtObject {\n\
                 property QtObject theme: Kirigami.Theme\n\
-            }", QUrl());
+            }", QUrl(QStringLiteral("basictheme.cpp")));
 
     QObject *obj = c.create();
     m_declarativeBasicTheme = obj->property("theme").value<QObject *>();
@@ -112,9 +99,9 @@ BasicTheme::BasicTheme(QObject *parent)
 
     connect(basicThemeDeclarative()->instance(this), SIGNAL(viewTextColorChanged()),
             basicThemeDeclarative()->m_colorSyncTimer, SLOT(start()));
-    connect(basicThemeDeclarative()->instance(this), SIGNAL(viewBackgroundColorChanged()), 
+    connect(basicThemeDeclarative()->instance(this), SIGNAL(viewBackgroundColorChanged()),
             basicThemeDeclarative()->m_colorSyncTimer, SLOT(start()));
-    connect(basicThemeDeclarative()->instance(this), SIGNAL(viewAlternateBackgroundColorChanged()), 
+    connect(basicThemeDeclarative()->instance(this), SIGNAL(viewAlternateBackgroundColorChanged()),
             basicThemeDeclarative()->m_colorSyncTimer, SLOT(start()));
     connect(basicThemeDeclarative()->instance(this), SIGNAL(viewHoverColorChanged()),
             basicThemeDeclarative()->m_colorSyncTimer, SLOT(start()));
@@ -213,16 +200,28 @@ void BasicTheme::syncColors()
         setHighlightedTextColor(PROXYCOLOR(highlightedTextColor, HighlightedTextColor));
     }{
         setActiveTextColor(PROXYCOLOR(activeTextColor, ActiveTextColor));
+    }{
+        setActiveBackgroundColor(PROXYCOLOR(activeBackgroundColor, ActiveBackgroundColor));
     }{
         setLinkColor(PROXYCOLOR(linkColor, LinkColor));
+    }{
+        setLinkBackgroundColor(PROXYCOLOR(linkBackgroundColor, LinkBackgroundColor));
     }{
         setVisitedLinkColor(PROXYCOLOR(visitedLinkColor, VisitedLinkColor));
+    }{
+        setVisitedLinkBackgroundColor(PROXYCOLOR(visitedLinkBackgroundColor, VisitedLinkBackgroundColor));
     }{
         setNegativeTextColor(PROXYCOLOR(negativeTextColor, NegativeTextColor));
+    }{
+        setNegativeBackgroundColor(PROXYCOLOR(negativeBackgroundColor, NegativeBackgroundColor));
     }{
         setNeutralTextColor(PROXYCOLOR(neutralTextColor, NeutralTextColor));
+    }{
+        setNeutralBackgroundColor(PROXYCOLOR(neutralBackgroundColor, NeutralBackgroundColor));
     }{
         setPositiveTextColor(PROXYCOLOR(positiveTextColor, PositiveTextColor));
+    }{
+        setPositiveBackgroundColor(PROXYCOLOR(positiveBackgroundColor, PositiveBackgroundColor));
     }{
         RESOLVECOLOR(hoverColor, HoverColor);
         setHoverColor(color);
